@@ -198,7 +198,7 @@ mixed<-function(x,y,kk){
     var<-diag(solve(xx)*sigma2)
     stderr<-sqrt(var)
     return(c(beta,stderr,sigma2))}
-  qq<-eigen(as.matrix(kk),symmetric=T,EISPACK=T)
+  qq<-eigen(as.matrix(kk),symmetric=T)
   delta<-qq[[1]]
   uu<-qq[[2]]
   q<-ncol(x)
@@ -227,7 +227,7 @@ mixed<-function(x,y,kk){
 
 # Shizhong's BLUP function
 blup<-function(gen,map,fam,x,y,kk,beta,lambda,cc){
-  qq<-eigen(as.matrix(kk),EISPACK=TRUE)
+  qq<-eigen(as.matrix(kk))
   delta<-qq[[1]]
   uu<-qq[[2]]
   yu<-t(uu)%*%y
@@ -275,7 +275,7 @@ RANDOMsma = function (GEN=GEN,MAP=MAP,fam=fam,chr=chr,y=y,COV=covariate,gen=gen,
   lambda<-parm$lambda
   beta<-parm$beta
   cat("Starting Eigendecomposition",'\n')
-  qq<-eigen(as.matrix(kk),symmetric=T,EISPACK=T)
+  qq<-eigen(as.matrix(kk),symmetric=T)
   delta<-qq[[1]]
   uu<-qq[[2]]
   h<-1/(delta*lambda+1)
@@ -375,7 +375,7 @@ RandomCIM = function (GEN=GEN,MAP=MAP,fam=fam,chr=chr,y=y,COV=covariate,WIN=wind
   lambda<-parm$lambda
   beta<-parm$beta
   cat("Starting Eigendecomposition",'\n')
-  qq<-eigen(as.matrix(kk),symmetric=T,EISPACK=T)
+  qq<-eigen(as.matrix(kk),symmetric=T)
   delta<-qq[[1]]
   uu<-qq[[2]]
   h<-1/(delta*lambda+1)
@@ -481,4 +481,5 @@ RandomCIM = function (GEN=GEN,MAP=MAP,fam=fam,chr=chr,y=y,COV=covariate,WIN=wind
 
 if(method=="RH"){fit=RANDOMsma(GEN=GEN,MAP=MAP,fam=fam,chr=chr,y=y,COV=covariate,gen=gen,SNPnames=SNPs)}
 if(method=="EB"){fit=RandomCIM(GEN=GEN,MAP=MAP,fam=fam,chr=chr,y=y,COV=covariate,WIN=window,gen=gen,SNPnames=SNPs)}
+neg = which(fit$PolyTest$lrt<0);fit$PolyTest$lrt[neg]=0
 return(fit)}
